#R-code of "Reorganization of interaction networks modulates the persistence of species in late successional stages" by:
#Serguei Saavedra, Simone Cenci, Ek del_val, Karina Boege, and Rudolf P. Rohr
#published in: Journal of Animal Ecology

rm(list=ls())
source('toolbox.r') #load the toolbox

web1 <- read.table('./data/late_A_7n.txt',header = TRUE) #load network before reorganization
web1 <- as.matrix(web1)
web1 <- web1[rowSums(web1)>0,colSums(web1)>0] # remove all columns and rows with no observations
web1 <- (web1>0)*1 # create binary matrix

web2 <- read.table('./data/late_A_8n.txt',header = TRUE) #load network after reorganization
web2 <- as.matrix(web2)
web2 <- web2[rowSums(web2)>0,colSums(web2)>0] # remove all columns and rows with no observations
web2 <- (web2>0)*1 # create binary matrix

p1 <- rownames(web1) #plants name of web1
h1 <- colnames(web1) #insect name of web1

p2 <- rownames(web2) #plants name of web2
h2 <- colnames(web2) #insect name of web2

p12 <- intersect(p1,p2) #resident plants between web1 and web2
h12 <- intersect(h1,h2) #resident insect between web1 and web2

#compute web2 without reoganization
web2_without <- web2
web2_without[p12,h12] <- web1[p12,h12]

#compute interaction matrix for web2 (after reorganization)
beta2 <- compute_interaction_matrix(t(web2))

#compute interaction matrix for web2 without reorganization
beta2_without <- compute_interaction_matrix(t(web2_without))

#compute the critical level of interspecific strength of web2
mu_max <- critical_interaction_level(beta2) 

alpha2 <- rescale_interaction_matrix(0.5*mu_max,beta2) #compute the interaction matrix for mu = 0.5*mu_max
alpha2_without <- rescale_interaction_matrix(0.5*mu_max,beta2_without) #compute the intreaction matrix for mu = 0.5*mu_max

r_S <- r_structural(alpha2) #compute the strucutral vector of alpha2
r_Sw <- r_structural(alpha2_without) #compute the strucutral vector of alpha2_without

#compute de difference in structural vector, i.e., the impact of network reoganization
Delta_r_S = abs(r_S - r_Sw)
