#R-code of "Reorganization of interaction networks modulates the persistence of species in late successional stages" by:
#Serguei Saavedra, Simone Cenci, Ek del_val, Karina Boege, and Rudolf P. Rohr
#published in: Journal of Animal Ecology

compute_interaction_matrix <- function(Y){
  #   compute_interaction_matrix Compute the interaction_ matrix from the plant-herbivore interaction network
  #   beta = compute_competition_matrix(Y) with
  #   beta = competition matrix among hervibores
  #   Y = agent-resource network (rows = herbivores, columns = plants)   
  beta <- Y %*% t(Y)
  diag(beta)[diag(beta)==0] <- 1
  return(beta)
}


rescale_interaction_matrix <- function(mu,beta_0){
  #   rescale_interaction_matrix Rescale the hervibore community
  #   beta=rescale_interaction_matrix(mu,beta0) with
  #   beta = rescaled interaction matrix among herbivores
  #   beta0 = original interaction matrix among herbivores
  #   mu = rescaling factor			  
  beta <- mu * beta_0 + (1-mu) * diag(diag(beta_0))
  return(beta)
}

critical_interaction_level <- function(beta){
  #	 critical_interaction_level Compute the critical level of interspecific effect in the community
  #   above which the global sability is lost
  #   mu_hat = critical_interaction_level(beta) with
  #   mu_hat = crtitcal level of interaction
  #   beta = competition matrix among herbivores
  tol <- 0.000001   
  mu_hat <- 0
  delta_mu <- 1
  step <- 0
  A <- rescale_interaction_matrix(mu_hat,beta)     
  tmp <- eigen(A)
  lambda <- tmp$values
  D <- Re(lambda)
  min_eig <- min(D)
  while ((abs(min_eig) > tol) && (step<50)){
    step = step + 1
    if (min_eig < 0) {
      mu_hat <- mu_hat - delta_mu
    }   else{
      mu_hat <- mu_hat + delta_mu
    }
    delta_mu <- delta_mu/2
    A <- rescale_interaction_matrix(mu_hat,beta)     
    tmp <- eigen(A)
    lambda <- tmp$values
    D <- Re(lambda)
    min_eig <- min(D)
  }
  return(mu_hat)
}     


r_structural <- function(alpha){
  #	  r_structural Compute the structural vector of the interaction matrix alpha (centroid of the feasibility domain)
  #   r_S = r_structural(alpha) with
  #   r_S = stuctural vector
  #   alpha = interaction matrix
  
  D <- diag(1/sqrt(diag(t(alpha)%*%alpha)))
  alpha_n <- alpha %*% D
  r_S <- rowSums(alpha_n)
  r_S <- r_S / sqrt((sum(r_S^2)))
  r_S <- t(t(r_S))
  return(r_S)
}


